diff --git a/MediaBrowser.Model/System/SystemInfo.cs b/MediaBrowser.Model/System/SystemInfo.cs
index 5fc5f363b6..3082e80b63 100644
--- a/MediaBrowser.Model/System/SystemInfo.cs
+++ b/MediaBrowser.Model/System/SystemInfo.cs
@@ -109,7 +109,13 @@ namespace MediaBrowser.Model.System
///
/// The log path.
public string LogPath { get; set; }
-
+
+ ///
+ /// Gets or sets the transcoding temporary path.
+ ///
+ /// The transcoding temporary path.
+ public string TranscodingTempPath { get; set; }
+
///
/// Gets or sets the HTTP server port number.
///
diff --git a/MediaBrowser.ServerApplication/ApplicationHost.cs b/MediaBrowser.ServerApplication/ApplicationHost.cs
index f6053f9981..84adffecb9 100644
--- a/MediaBrowser.ServerApplication/ApplicationHost.cs
+++ b/MediaBrowser.ServerApplication/ApplicationHost.cs
@@ -642,7 +642,8 @@ namespace MediaBrowser.ServerApplication
CanSelfUpdate = CanSelfUpdate,
WanAddress = GetWanAddress(),
HasUpdateAvailable = _hasUpdateAvailable,
- SupportsAutoRunAtStartup = SupportsAutoRunAtStartup
+ SupportsAutoRunAtStartup = SupportsAutoRunAtStartup,
+ TranscodingTempPath = ApplicationPaths.TranscodingTempPath
};
}
diff --git a/MediaBrowser.WebDashboard/Api/DashboardService.cs b/MediaBrowser.WebDashboard/Api/DashboardService.cs
index 93bf768e69..a02da385da 100644
--- a/MediaBrowser.WebDashboard/Api/DashboardService.cs
+++ b/MediaBrowser.WebDashboard/Api/DashboardService.cs
@@ -476,6 +476,7 @@ namespace MediaBrowser.WebDashboard.Api
"metadataadvanced.js",
"appsplayback.js",
"appsweather.js",
+ "dashboardinfo.js",
"dashboardpage.js",
"directorybrowser.js",
"edititemmetadata.js",
diff --git a/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj b/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
index 78164a5af7..2066c6cb93 100644
--- a/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
+++ b/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
@@ -163,6 +163,9 @@
PreserveNewest
+
+ PreserveNewest
+
PreserveNewest
@@ -409,6 +412,9 @@
PreserveNewest
+
+ PreserveNewest
+
PreserveNewest
diff --git a/MediaBrowser.WebDashboard/packages.config b/MediaBrowser.WebDashboard/packages.config
index 56158ace7c..321ffd45c3 100644
--- a/MediaBrowser.WebDashboard/packages.config
+++ b/MediaBrowser.WebDashboard/packages.config
@@ -1,4 +1,4 @@
-
+
\ No newline at end of file
diff --git a/MediaBrowser.WebDashboard/ApiClient.js b/MediaBrowser.WebDashboard/ApiClient.js
index e790a1836c..d8a1c45ce6 100644
--- a/MediaBrowser.WebDashboard/ApiClient.js
+++ b/MediaBrowser.WebDashboard/ApiClient.js
@@ -6,19 +6,14 @@ MediaBrowser.ApiClient = function ($, navigator, JSON, WebSocket, setTimeout, wi
/**
* Creates a new api client instance
- * @param {String} serverProtocol
- * @param {String} serverHostName
- * @param {String} serverPortNumber
+ * @param {String} serverAddress
* @param {String} clientName
* @param {String} applicationVersion
*/
- return function (serverProtocol, serverHostName, serverPortNumber, clientName, applicationVersion) {
+ return function (serverAddress, clientName, applicationVersion) {
- if (!serverProtocol) {
- throw new Error("Must supply a serverProtocol, e.g. http:");
- }
- if (!serverHostName) {
- throw new Error("Must supply serverHostName, e.g. 192.168.1.1 or myServerName");
+ if (!serverAddress) {
+ throw new Error("Must supply a serverAddress");
}
var self = this;
@@ -28,11 +23,11 @@ MediaBrowser.ApiClient = function ($, navigator, JSON, WebSocket, setTimeout, wi
var webSocket;
/**
* Gets the server host name.
*/
- self.serverHostName = function () {
+ self.serverAddress = function () {
- return serverHostName;
+ return serverAddress;
};
/**
@@ -133,11 +128,7 @@ MediaBrowser.ApiClient = function ($, navigator, JSON, WebSocket, setTimeout, wi
throw new Error("Url name cannot be empty");
}
- var url = serverProtocol + "//" + serverHostName;
-
- if (serverPortNumber) {
- url += ":" + serverPortNumber;
- }
+ var url = serverAddress;
url += "/mediabrowser/" + name;
@@ -148,9 +139,9 @@ MediaBrowser.ApiClient = function ($, navigator, JSON, WebSocket, setTimeout, wi
return url;
};
- self.openWebSocket = function (port) {
+ self.openWebSocket = function (webSocketAddress) {
- var url = "ws://" + serverHostName + ":" + port + "/mediabrowser";
+ var url = webSocketAddress + "/mediabrowser";
webSocket = new WebSocket(url);
@@ -3998,7 +3989,13 @@ MediaBrowser.ApiClient.create = function (clientName, applicationVersion) {
var loc = window.location;
- return new MediaBrowser.ApiClient(loc.protocol, loc.hostname, loc.port, clientName, applicationVersion);
+ var address = loc.protocol + '//' + loc.hostname;
+
+ if (loc.port) {
+ address += ':' + loc.port;
+ }
+
+ return new MediaBrowser.ApiClient(address, clientName, applicationVersion);
};
/**
@@ -28,11 +23,11 @@ MediaBrowser.ApiClient = function ($, navigator, JSON, WebSocket, setTimeout, wi
var webSocket;
/**
- * Gets the server host name.
+ * Gets the server address.
*/